Crate bevy_family

Crate bevy_family 

Structs

BiologicalClock
A component that represents the entity’s lifetime.
CudEvent
Event that is used to create, update and delete parent entities
FamilyPlugin
Main Plugin for the Family Plugin
History
History of the action that has been performed
Identifier
Unique identifier for the entities.
Lineage
Lineage of the actions that have been performed

Enums

Action
Action to interact with the entities.

Traits

BiologicalTrait

Functions

cud_bundle
get_entity_by_identifier
Get the entity by the identifier.
refresh_by_own_lifetime
Acts like a garbage collector to remove entities that have exceeded their own lifetime
refresh_by_parent_lifetime
Acts like a garbage collector to remove entities that have exceeded their parent’s lifetime