Structs
- Biological
Clock - A component that represents the entity’s lifetime.
- CudEvent
- Event that is used to create, update and delete parent entities
- Family
Plugin - Main Plugin for the Family Plugin
- History
- History of the action that has been performed
- Identifier
- Unique identifier for the entities.
- Lineage
- Lineage of the actions that have been performed
Enums
- Action
- Action to interact with the entities.
Traits
Functions
- cud_
bundle - get_
entity_ by_ identifier - Get the entity by the identifier.
- refresh_
by_ own_ lifetime - Acts like a garbage collector to remove entities that have exceeded their own lifetime
- refresh_
by_ parent_ lifetime - Acts like a garbage collector to remove entities that have exceeded their parent’s lifetime